get_account_interest_rate: Get account borrowing interest rates

View source: R/wrappers_get_account.R

get_account_interest_rateR Documentation

Get account borrowing interest rates

Description

Retrieve the current leveraged currency borrowing market interest rate for one currency or for all eligible currencies.

Usage

get_account_interest_rate(
  ccy = NULL,
  config,
  tz = .okx_default_tz
)

Arguments

ccy

Character or 'NULL'. Currency filter, e.g. '"BTC"'.

config

List. API credentials/config.

tz

Character. Time zone for parsing timestamps. Default '"Asia/Hong_Kong"'.

Value

A 'data.frame' with 'ccy' and 'interestRate'.


okxr documentation built on May 8, 2026, 5:09 p.m.