get_market_option_instrument_family_trades: Get option trades by instrument family

View source: R/wrappers_get_market.R

get_market_option_instrument_family_tradesR Documentation

Get option trades by instrument family

Description

Retrieve recent option trades for all instruments under the same instrument family.

Usage

get_market_option_instrument_family_trades(
  inst_family,
  config = NULL,
  tz = .okx_default_tz
)

Arguments

inst_family

Character. Instrument family, e.g. '"BTC-USD"'.

config

Optional list. Public endpoint request options, such as 'timeout'; credentials are not required.

tz

Character. Time zone for parsing timestamps. Default '"Asia/Hong_Kong"'.

Value

A 'data.frame' with recent option trades under the requested instrument family, including 'instId', 'tradeId', 'px', 'sz', 'side', and 'ts'.


okxr documentation built on May 8, 2026, 5:09 p.m.