get_public_funding_rate: Get current funding rate

View source: R/wrappers_get_market.R

get_public_funding_rateR Documentation

Get current funding rate

Description

Retrieve the current funding rate for a perpetual swap instrument.

Usage

get_public_funding_rate(
  inst_id,
  config = NULL,
  tz = .okx_default_tz
)

Arguments

inst_id

Character. Instrument ID, e.g. '"BTC-USDT-SWAP"'.

config

Optional list. Public endpoint request options, such as 'timeout'; credentials are not required.

tz

Character. Time zone for parsing timestamps. Default '"Asia/Hong_Kong"'.

Value

A 'data.frame' containing the current funding rate fields returned by OKX.


okxr documentation built on May 8, 2026, 5:09 p.m.