get_public_funding_rate_history: Get funding rate history

View source: R/wrappers_get_market.R

get_public_funding_rate_historyR Documentation

Get funding rate history

Description

Retrieve historical funding rate entries for a perpetual swap instrument.

Usage

get_public_funding_rate_history(
  inst_id,
  before = NULL,
  after = NULL,
  limit = 400,
  config = NULL,
  tz = .okx_default_tz
)

Arguments

inst_id

Character. Instrument ID, e.g. '"BTC-USDT-SWAP"'.

before

Optional cursor for records earlier than the supplied value.

after

Optional cursor for records later than the supplied value.

limit

Integer. Number of records to request. Default '400'.

config

Optional list. Public endpoint request options, such as 'timeout'; credentials are not required.

tz

Character. Time zone for parsing timestamps. Default '"Asia/Hong_Kong"'.

Value

A 'data.frame' containing funding rate history rows returned by OKX.


okxr documentation built on May 8, 2026, 5:09 p.m.