View source: R/wrappers_get_trade.R
| get_trade_account_rate_limit | R Documentation |
Retrieve account rate limit information related to new and amended order requests.
get_trade_account_rate_limit(config, tz = .okx_default_tz)
config |
List. API credentials/config. |
tz |
Character. Time zone for parsing timestamps. Default '"Asia/Hong_Kong"'. |
Wraps '/api/v5/trade/account-rate-limit'. Returns one row containing the current account rate limit and fill-ratio metrics used by OKX.
A one-row 'data.frame' with rate-limit metrics such as 'accRateLimit', 'fillRatio', 'mainFillRatio', 'nextAccRateLimit', and 'ts'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.