View source: R/wrappers_get_account.R
| get_account_interest_rate | R Documentation |
Retrieve the current leveraged currency borrowing market interest rate for one currency or for all eligible currencies.
get_account_interest_rate(
ccy = NULL,
config,
tz = .okx_default_tz
)
ccy |
Character or 'NULL'. Currency filter, e.g. '"BTC"'. |
config |
List. API credentials/config. |
tz |
Character. Time zone for parsing timestamps. Default '"Asia/Hong_Kong"'. |
A 'data.frame' with 'ccy' and 'interestRate'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.