View source: R/wrappers_get_account.R
| get_account_trade_fee | R Documentation |
Retrieve the account's trade fee schedule for a specific instrument type and optional instrument, instrument family, or trading fee group.
get_account_trade_fee(
inst_type,
inst_id = NULL,
inst_family = NULL,
group_id = NULL,
config,
tz = .okx_default_tz
)
inst_type |
Character. Instrument type. One of '"SPOT"', '"MARGIN"', '"SWAP"', '"FUTURES"', '"OPTION"', or '"EVENTS"'. |
inst_id |
Character or 'NULL'. Instrument ID for spot or margin. |
inst_family |
Character or 'NULL'. Instrument family for futures, swaps, or options. |
group_id |
Character or 'NULL'. Trading fee group ID. Use this by itself. |
config |
List. API credentials/config. |
tz |
Character. Time zone for parsing timestamps. Default '"Asia/Hong_Kong"'. |
A 'data.frame' with fee level, fee-rate columns, and any nested 'feeGroup' or deprecated 'fiat' details JSON-encoded as strings.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.