View source: R/wrappers_get_asset.R
| get_asset_deposit_history | R Documentation |
Retrieves a record of all asset deposits made to your account.
get_asset_deposit_history(
ccy = NULL,
dep_id = NULL,
from_wd_id = NULL,
tx_id = NULL,
type = NULL,
state = NULL,
after = NULL,
before = NULL,
limit = NULL,
config,
tz = .okx_default_tz
)
ccy |
Character or 'NULL'. Currency filter. |
dep_id |
Character or 'NULL'. Deposit ID filter. |
from_wd_id |
Character or 'NULL'. Source withdrawal ID filter. |
tx_id |
Character or 'NULL'. Transaction hash filter. |
type |
Character or 'NULL'. Deposit type filter. |
state |
Character or 'NULL'. Deposit state filter. |
after |
Character or 'NULL'. Pagination cursor for earlier records. |
before |
Character or 'NULL'. Pagination cursor for newer records. |
limit |
Integer or 'NULL'. Number of rows to request. |
config |
API credentials as a list with |
tz |
Timezone string (default: |
A data.frame with deposit history rows and detailed transfer metadata.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.