View source: R/wrappers_get_asset.R
| get_asset_withdrawal_history | R Documentation |
Retrieves a record of all asset withdrawals from your account.
get_asset_withdrawal_history(
ccy = NULL,
wd_id = NULL,
client_id = NULL,
tx_id = NULL,
type = NULL,
state = NULL,
after = NULL,
before = NULL,
limit = NULL,
config,
tz = .okx_default_tz
)
ccy |
Character or 'NULL'. Currency filter. |
wd_id |
Character or 'NULL'. Withdrawal ID filter. |
client_id |
Character or 'NULL'. Client withdrawal ID filter. |
tx_id |
Character or 'NULL'. Transaction hash filter. |
type |
Character or 'NULL'. Withdrawal type filter. |
state |
Character or 'NULL'. Withdrawal state filter. |
after |
Character or 'NULL'. Pagination cursor for earlier records. |
before |
Character or 'NULL'. Pagination cursor for newer records. |
limit |
Integer or 'NULL'. Number of rows to request. |
config |
API credentials as a list with |
tz |
Timezone string (default: |
A data.frame with withdrawal history rows and detailed transfer metadata.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.