View source: R/wrappers_get_market.R
| get_market_option_instrument_family_trades | R Documentation |
Retrieve recent option trades for all instruments under the same instrument family.
get_market_option_instrument_family_trades(
inst_family,
config = NULL,
tz = .okx_default_tz
)
inst_family |
Character. Instrument family, e.g. '"BTC-USD"'. |
config |
Optional list. Public endpoint request options, such as 'timeout'; credentials are not required. |
tz |
Character. Time zone for parsing timestamps. Default '"Asia/Hong_Kong"'. |
A 'data.frame' with recent option trades under the requested instrument family, including 'instId', 'tradeId', 'px', 'sz', 'side', and 'ts'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.