View source: R/wrappers_get_market.R
| get_public_funding_rate | R Documentation |
Retrieve the current funding rate for a perpetual swap instrument.
get_public_funding_rate(
inst_id,
config = NULL,
tz = .okx_default_tz
)
inst_id |
Character. Instrument ID, e.g. '"BTC-USDT-SWAP"'. |
config |
Optional list. Public endpoint request options, such as 'timeout'; credentials are not required. |
tz |
Character. Time zone for parsing timestamps. Default '"Asia/Hong_Kong"'. |
A 'data.frame' containing the current funding rate fields returned by OKX.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.