View source: R/wrappers_get_market.R
| get_public_opt_summary | R Documentation |
Retrieve option market summary data for an instrument family.
get_public_opt_summary(
inst_family,
exp_time = NULL,
config = NULL,
tz = .okx_default_tz
)
inst_family |
Character. Option instrument family. |
exp_time |
Character or 'NULL'. Expiry date in 'YYMMDD'. |
config |
Optional list. Public endpoint request options, such as 'timeout'; credentials are not required. |
tz |
Character. Time zone for parsing timestamps. Default '"Asia/Hong_Kong"'. |
A 'data.frame' with option greeks, volatility, forward price, and timestamp fields.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.