View source: R/wrappers_get_market.R
| get_public_option_trades | R Documentation |
Retrieve recent public option trades filtered by instrument ID or instrument family.
get_public_option_trades(
inst_id = NULL,
inst_family = NULL,
opt_type = NULL,
config = NULL,
tz = .okx_default_tz
)
inst_id |
Character or 'NULL'. Specific option instrument ID. |
inst_family |
Character or 'NULL'. Option instrument family, e.g. '"BTC-USD"'. Either 'inst_id' or 'inst_family' should be supplied. |
opt_type |
Character or 'NULL'. Option type filter: '"C"' for call or '"P"' for put. |
config |
Optional list. Public endpoint request options, such as 'timeout'; credentials are not required. |
tz |
Character. Time zone for parsing timestamps. Default '"Asia/Hong_Kong"'. |
A 'data.frame' with recent option trade rows, including option instrument identifiers, trade price and size, option side/type, forward, index and mark prices, implied volatility, and trade time.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.