| get_var_label | R Documentation |
Returns human-readable labels attached to a data frame produced by OKX API parsers. You can retrieve all labels or a label for a specific variable by name or index.
get_var_label(df, var = NULL, default = NA_character_)
df |
A |
var |
Optional variable name (character) or index (numeric). If |
default |
Value to return if the variable has no label (default: |
A character label if var is provided, or a named character vector of all labels if var = NULL.
df <- data.frame(ordId = "123", px = 10)
attr(df, "var_labels") <- c(ordId = "Order ID", px = "Price")
get_var_label(df, "ordId")
get_var_label(df, 2)
get_var_label(df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.